@@ -86,9 +86,13 @@ CDesktop::CDesktop()
     // Rds Broadcast writer 
     rdsBroadcast = new CRdsBroadcast(this);
 
+    // Rds Broadcast writer
+    rdsSms = new CSms(this);
+
     // Connect signal changed
     connect(rdsMafw, SIGNAL(sigChanged(QString,int)), rdsBroadcast, SLOT(slotSetText(QString,int)));
     connect(rdsRTCom, SIGNAL(sigChanged(QString,int)), rdsBroadcast, SLOT(slotSetText(QString,int)));
+    connect(rdsSms, SIGNAL(sigChanged(QString,int)), rdsBroadcast, SLOT(slotSetText(QString,int)));
 
     QDBusConnection::systemBus().connect( 0, FMTX_PATH, FMTX_IF,  "info", this, SLOT(slotFMTXChanged(QString,QString)));
     
@@ -180,7 +184,7 @@ void CDesktop::drawDesktop(QPainter *p)
     
     QRectF smsStatus = renderer->boundsOnElement("SMS_STATUS");
     if ( state)
-        drawStatus(p, smsStatus , false );
+        drawStatus(p, smsStatus , CSms::self().getEnable() );
 
     QFont localFont = p->font();
     localFont.setPointSize(14);
@@ -213,6 +217,7 @@ void CDesktop::slotFMTXChanged(QString type, QString status)
     if (type == "connected") {
 	rdsMafw->setConnect(status.toInt() );
 	rdsRTCom->setConnect(status.toInt() );
+        rdsSms->setConnect(status.toInt() );
 	dirty = true;
 	state = status.toInt();
 	update();
