@@ -26,6 +26,7 @@
 #include "dbus-strings.h"
 #include "CMafwMeta.h"
 #include "CRTCom.h"
+#include "CSms.h"
 #include "CRdsBroadcast.h"
 #include <QWidget>
 #include <QPixmap>
@@ -50,6 +51,7 @@ private:
     int state;
     CMafwMeta *rdsMafw;
     CRTCom *rdsRTCom;
+    CSms *rdsSms;
     CRdsBroadcast *rdsBroadcast;
     void drawDesktop(QPainter *p);
     void drawStatus(QPainter *p, QRectF rect, bool status);
