@@ -68,21 +68,17 @@ CRdsBroadcast::~CRdsBroadcast()
 void CRdsBroadcast::slotSetText(QString text, int timeout)
 {
      endTime = timeout;
-     if (withDBus) {
-	     setDBusText(text.leftJustified(8,' ',true) );
-     } else {
-	     // Cut text into parts depending of length
-	     // and call every delay to display each part
-	     textPart->clear();
-	     int cur=0;
-	     while (cur < text.size()-1 ) {
-		     textPart->append( text.mid(cur , display) );
-		     cur = cur + display;
-	     }
-	     textCount=0;
-	     timer->start(refresh);
-	     timerTimeout->start(endTime);
+     // Cut text into parts depending of length
+     // and call every delay to display each part
+     textPart->clear();
+     int cur=0;
+     while (cur < text.size()-1 ) {
+	     textPart->append( text.mid(cur , display) );
+	     cur = cur + display;
      }
+     textCount=0;
+     timer->start(refresh);
+     timerTimeout->start(endTime);
 }
 
 void CRdsBroadcast::slotEndText()
@@ -92,7 +88,7 @@ void CRdsBroadcast::slotEndText()
      timer->stop();
      timerTimeout->stop();
      if (withDBus) {
-	 setDBusText(defText );
+	 setDBusText(defText.leftJustified(8,' ',true) );
      } else
      {
 	 setSystemText(defText );
@@ -144,7 +140,11 @@ void CRdsBroadcast::slotUpdateText()
     if (textCount > textPart->size()-1 ) {
 	    textCount = 0;
     }
-    setSystemText(textPart->at(textCount) );
+    if (withDBus) {
+    	setDBusText(textPart->at(textCount).leftJustified(8,' ',true) );
+    } else {
+    	setSystemText(textPart->at(textCount) );
+    }
     //qDebug() << "RDS text" << textPart->at(textCount);
     
     textCount++;
